Learn R Programming

r2pptx (version 0.1.0)

R2PptxLocation-class: Location

Description

A Location is used to place an element on a slide. For now this will just be a placeholder name, but eventually it could expand to be an arbitrary location

Arguments