Learn R Programming

r2pptx (version 0.1.0)

R2PptxSlideList-class: Slide list

Description

R2PptxSlideList is an S4 class to contain groups of R2PptxSlide objects that are not part of a presentation. It is meant to be used to create lists of slides and then be able to add the list easily to a presentation.

Arguments

Slots

slides

list. A list of R2PptxSlide objects