Gets all the layout properties for all the layouts in a presentation

get_all_layout_properties(x)

Arguments

x

R2PpptxPresentation object

Value

An object of class data.frame with fields for placeholder attributes and one row per placeholder element per layout.