R/utils.R
get_all_layout_properties.Rd
Gets all the layout properties for all the layouts in a presentation
get_all_layout_properties(x)
R2PpptxPresentation object
R2PpptxPresentation
An object of class data.frame with fields for placeholder attributes and one row per placeholder element per layout.
data.frame